@@ -6,6 +6,8 @@ from rest_framework.serializers import _resolve_model
 from rest_framework.authtoken.models import Token
 
 
+profile_model_path = lambda: getattr(settings, 'REST_PROFILE_MODULE', None)
+
 class LoginSerializer(serializers.Serializer):
     username = serializers.CharField(max_length=30)
     password = serializers.CharField(max_length=128)
@@ -22,28 +24,6 @@ class TokenSerializer(serializers.ModelSerializer):
         fields = ('key',)
 
 
-class UserRegistrationSerializer(serializers.ModelSerializer):
-
-    """
-    Serializer for Django User model and most of its fields.
-    """
-
-    class Meta:
-        model = get_user_model()
-        fields = ('username', 'password', 'email', 'first_name', 'last_name')
-
-
-class UserRegistrationProfileSerializer(serializers.ModelSerializer):
-
-    """
-    Serializer that includes all profile fields except for user fk / id.
-    """
-    class Meta:
-        model = _resolve_model(getattr(settings, 'REST_PROFILE_MODULE', None))
-        fields = filter(lambda x: x != 'id' and x != 'user',
-                        map(lambda x: x.name, model._meta.fields))
-
-
 class UserDetailsSerializer(serializers.ModelSerializer):
 
     """
@@ -54,17 +34,15 @@ class UserDetailsSerializer(serializers.ModelSerializer):
         fields = ('username', 'email', 'first_name', 'last_name')
 
 
-class UserProfileSerializer(serializers.ModelSerializer):
+class UserRegistrationSerializer(serializers.ModelSerializer):
 
     """
-    Serializer for UserProfile model.
+    Serializer for Django User model and most of its fields.
     """
 
-    user = UserDetailsSerializer()
-
     class Meta:
-        # http://stackoverflow.com/questions/4881607/django-get-model-from-string
-        model = _resolve_model(getattr(settings, 'REST_PROFILE_MODULE', None))
+        model = get_user_model()
+        fields = ('username', 'password', 'email', 'first_name', 'last_name')
 
 
 class DynamicFieldsModelSerializer(serializers.ModelSerializer):
@@ -96,17 +74,64 @@ class UserUpdateSerializer(DynamicFieldsModelSerializer):
         fields = ('id', 'email', 'first_name', 'last_name')
 
 
-class UserProfileUpdateSerializer(serializers.ModelSerializer):
 
-    """
-    Serializer for updating User and UserProfile model.
-    """
+def get_user_registration_profile_serializer():
+    if profile_model_path():
+        class UserRegistrationProfileSerializer(serializers.ModelSerializer):
 
-    user = UserUpdateSerializer()
+            """
+            Serializer that includes all profile fields except for user fk / id.
+            """
+            class Meta:
 
-    class Meta:
-        # http://stackoverflow.com/questions/4881607/django-get-model-from-string
-        model = _resolve_model(getattr(settings, 'REST_PROFILE_MODULE', None))
+                model = _resolve_model(profile_model_path())
+                fields = filter(lambda x: x != 'id' and x != 'user',
+                                map(lambda x: x.name, model._meta.fields))
+    else:
+        class UserRegistrationProfileSerializer(serializers.Serializer):
+            pass
+    return UserRegistrationProfileSerializer
+
+
+def get_user_profile_serializer():
+    if profile_model_path():
+        class UserProfileSerializer(serializers.ModelSerializer):
+
+            """
+            Serializer for UserProfile model.
+            """
+
+            user = UserDetailsSerializer()
+
+            class Meta:
+                # http://stackoverflow.com/questions/4881607/django-get-model-from-string
+                model = _resolve_model(profile_model_path())
+
+            def __init__(self, *args, **kwargs):
+                super(UserProfileSerializer, self).__init__(*args, **kwargs)
+    else:
+        class UserProfileSerializer(serializers.Serializer):
+            pass
+    return UserProfileSerializer
+
+
+def get_user_profile_update_serializer():
+    if profile_model_path():
+        class UserProfileUpdateSerializer(serializers.ModelSerializer):
+
+            """
+            Serializer for updating User and UserProfile model.
+            """
+
+            user = UserUpdateSerializer()
+
+            class Meta:
+                # http://stackoverflow.com/questions/4881607/django-get-model-from-string
+                model = _resolve_model(profile_model_path())
+    else:
+        class UserProfileUpdateSerializer(serializers.Serializer):
+            pass
+    return UserProfileUpdateSerializer
 
 
 class SetPasswordSerializer(serializers.Serializer):
